@@ -225,14 +225,15 @@ class Metric(ABC, Generic[MetricType]):
                 return "(" + ",".join(cls.format_value(v) for v in value) + ")"
         if isinstance(value, (list)):
             if len(value) == 0:
-                return "[]"
+                return ""
             else:
-                return "[" + ",".join(cls.format_value(v) for v in value) + "]"
+                return ",".join(cls.format_value(v) for v in value)
         if isinstance(value, (set)):
             if len(value) == 0:
                 return ""
             else:
                 return "{" + ",".join(cls.format_value(v) for v in value) + "}"
+
         elif isinstance(value, dict):
             if len(value) == 0:
                 return "{}"
@@ -246,6 +247,8 @@ class Metric(ABC, Generic[MetricType]):
                 )
         elif isinstance(value, float):
             return str(round(value, 5))
+        elif value is None:
+            return ""
         else:
             return str(value)
 
